@@ -1,8 +1,33 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+/*
+ *  oafd: OAF CORBA dameon.
+ *
+ *  Copyright (C) 1999, 2000 Red Hat, Inc.
+ *  Copyright (C) 1999, 2000 Eazel, Inc.
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of the
+ *  License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors: Elliot Lee <sopwith@redhat.com>,
+ *
+ */
+
 #include "config.h"
 
 #include "oafd.h"
 #include "liboaf/liboaf-private.h"
+#include "oaf-i18n.h"
 
 #include <signal.h>
 #include <ctype.h>
@@ -32,7 +57,7 @@ od_server_activate (OAF_ServerInfo * si, ODActivationInfo * actinfo,
 
 	else if (!strcmp (si->server_type, "shlib"))
 		g_warning
-			("We don't handle activating shlib objects in a remote process yet");
+			(_("We don't handle activating shlib objects in a remote process yet"));
 
 	return CORBA_OBJECT_NIL;
 }
@@ -43,16 +68,17 @@ od_server_activate_factory (OAF_ServerInfo * si, ODActivationInfo * actinfo,
 {
 	CORBA_Object retval = CORBA_OBJECT_NIL, factory = CORBA_OBJECT_NIL;
 	OAF_ActivationResult *res;
-	GNOME_stringlist dummy = { 0 };
+	GNOME_stringlist params = { 0 };
 
 	res =
 		OAF_ActivationContext_activate_from_id (actinfo->ac,
 							si->location_info,
 							((actinfo->flags |
 							  OAF_FLAG_NO_LOCAL) &
-							 (~OAF_FLAG_IGNORE_EXISTING)),
+							 (~OAF_FLAG_PRIVATE)),
 							oaf_context_get (),
 							ev);
+
 	if (ev->_major != CORBA_NO_EXCEPTION)
 		goto out;
 
@@ -70,7 +96,7 @@ od_server_activate_factory (OAF_ServerInfo * si, ODActivationInfo * actinfo,
 	}
 
 	retval =
-		GNOME_GenericFactory_create_object (factory, si->iid, &dummy,
+		GNOME_ObjectFactory_create_object (factory, si->iid, &params,
 						    ev);
 	if (ev->_major != CORBA_NO_EXCEPTION)
 		retval = CORBA_OBJECT_NIL;
@@ -139,8 +165,15 @@ od_server_activate_exe (OAF_ServerInfo * si, ODActivationInfo * actinfo,
                 CORBA_free (iorstr);
         }
 
+        if(actinfo->flags & OAF_FLAG_PRIVATE) {
+                extra_arg =
+                        oaf_alloca (sizeof ("--oaf-private"));
+                args[i++] = extra_arg;
+                g_snprintf (extra_arg, sizeof ("--oaf-private"),
+                            "--oaf-private");
+        }
+
 	args[i] = NULL;
 
 	return oaf_server_by_forking ((const char **) args, fd_arg, ev);
 }
-
